from pydantic import BaseModel
from datetime import datetime
from typing import Optional

# Shared properties
class TodoBase(BaseModel):
    title: str
    description: Optional[str] = None
    completed: bool = False

# Properties to receive on creation
class TodoCreate(TodoBase):
    pass

# Properties to receive on update
class TodoUpdate(TodoBase):
    title: Optional[str] = None
    completed: Optional[bool] = None

# Properties to return to client
class TodoResponse(TodoBase):
    id: int
    created_at: datetime
    updated_at: Optional[datetime] = None

    class Config:
        from_attributes = True